MathExpr

Enum MathExpr 

pub enum MathExpr {
Show 34 variants Ident { value: String, }, Number { value: String, }, Operator(MathOperator), Text { value: String, }, Row { children: Vec<MathExpr>, }, Fenced { open: Delimiter, close: Delimiter, body: Vec<MathExpr>, }, Superscript { base: Box<MathExpr>, script: Box<MathExpr>, }, Subscript { base: Box<MathExpr>, script: Box<MathExpr>, }, Subsuperscript { base: Box<MathExpr>, sub: Box<MathExpr>, sup: Box<MathExpr>, }, Frac { numerator: Box<MathExpr>, denominator: Box<MathExpr>, style: FracStyle, }, Sqrt { index: Option<Box<MathExpr>>, body: Box<MathExpr>, }, Overline { body: Box<MathExpr>, }, Underline { body: Box<MathExpr>, }, Overbrace { body: Box<MathExpr>, annotation: Option<Box<MathExpr>>, }, Underbrace { body: Box<MathExpr>, annotation: Option<Box<MathExpr>>, }, Overset { over: Box<MathExpr>, base: Box<MathExpr>, }, Underset { under: Box<MathExpr>, base: Box<MathExpr>, }, Accent { kind: AccentKind, body: Box<MathExpr>, }, BigOperator { op: MathOperator, limits: LimitStyle, lower: Option<Box<MathExpr>>, upper: Option<Box<MathExpr>>, }, Matrix { rows: Vec<Vec<MathExpr>>, delimiters: MatrixDelimiters, }, Cases { rows: Vec<CaseRow>, }, Array { columns: Vec<ColumnAlign>, rows: Vec<Vec<MathExpr>>, }, Align { rows: Vec<AlignRow>, numbered: bool, }, Gather { rows: Vec<MathExpr>, numbered: bool, }, Space(MathSpace), Phantom { body: Box<MathExpr>, }, HPhantom { body: Box<MathExpr>, }, VPhantom { body: Box<MathExpr>, }, Smash { body: Box<MathExpr>, mode: SmashMode, }, StyleOverride { style: MathStyle, body: Box<MathExpr>, }, FontOverride { font: MathFont, body: Box<MathExpr>, }, Color { color: String, body: Box<MathExpr>, }, Chem { value: String, }, Error { raw: String, message: String, },
}
Structured math expression tree (Section 2.11).

This is a recursive algebraic type representing the parsed structure of a LaTeX math expression. Box<MathExpr> is used for recursive fields to keep the type sized.

Variants



Ident

Fields

value: String


Number

Fields

value: String


Operator(MathOperator)



Text

Fields

value: String


Row

Fields

children: Vec<MathExpr>


Fenced

Fields



Superscript

Fields

script: Box<MathExpr>


Subscript

Fields

script: Box<MathExpr>


Subsuperscript

Fields



Frac

Fields

numerator: Box<MathExpr>
denominator: Box<MathExpr>


Sqrt

Fields



Overline

Fields



Underline

Fields



Overbrace

Fields

annotation: Option<Box<MathExpr>>


Underbrace

Fields

annotation: Option<Box<MathExpr>>


Overset

Fields



Underset

Fields

under: Box<MathExpr>


Accent

Fields



BigOperator



Matrix

Fields

delimiters: MatrixDelimiters


Cases

Fields

rows: Vec<CaseRow>


Array

Fields

columns: Vec<ColumnAlign>


Align

Fields

numbered: bool


Gather

Fields

numbered: bool


Space(MathSpace)



Phantom

Fields



HPhantom

Fields



VPhantom

Fields



Smash

Fields



StyleOverride

Fields



FontOverride

Fields



Color

Fields

color: String


Chem

Fields

value: String


Error

Fields

message: String